summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--sql/events.cc2
-rw-r--r--sql/handler.cc4
-rw-r--r--sql/repl_failsafe.cc4
-rw-r--r--sql/slave.cc2
-rw-r--r--sql/sp.cc2
-rw-r--r--sql/sp_head.cc4
-rw-r--r--sql/sql_acl.cc2
-rw-r--r--sql/sql_class.cc2
-rw-r--r--sql/sql_class.h6
-rw-r--r--sql/sql_error.cc2
-rw-r--r--sql/sql_handler.cc2
-rw-r--r--sql/sql_help.cc2
-rw-r--r--sql/sql_parse.cc8
-rw-r--r--sql/sql_prepare.cc2
-rw-r--r--sql/sql_repl.cc8
-rw-r--r--sql/sql_show.cc18
-rw-r--r--sql/sql_table.cc4
17 files changed, 37 insertions, 37 deletions
diff --git a/sql/events.cc b/sql/events.cc
index 87385082a82..fc736a5379b 100644
--- a/sql/events.cc
+++ b/sql/events.cc
@@ -737,7 +737,7 @@ send_show_create_event(THD *thd, Event_timed *et, Protocol *protocol)
if (protocol->write())
DBUG_RETURN(TRUE);
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
diff --git a/sql/handler.cc b/sql/handler.cc
index d831a1c53a0..4cf73874f22 100644
--- a/sql/handler.cc
+++ b/sql/handler.cc
@@ -1590,7 +1590,7 @@ bool mysql_xa_recover(THD *thd)
}
pthread_mutex_unlock(&LOCK_xid_cache);
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(0);
}
@@ -4309,7 +4309,7 @@ bool ha_show_status(THD *thd, handlerton *db_type, enum ha_stat_type stat)
}
if (!result)
- send_eof(thd);
+ my_eof(thd);
return result;
}
diff --git a/sql/repl_failsafe.cc b/sql/repl_failsafe.cc
index 6f4b4b2571d..f8f01d2cad1 100644
--- a/sql/repl_failsafe.cc
+++ b/sql/repl_failsafe.cc
@@ -475,7 +475,7 @@ bool show_new_master(THD* thd)
protocol->store((ulonglong) lex_mi->pos);
if (protocol->write())
DBUG_RETURN(TRUE);
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
}
@@ -688,7 +688,7 @@ bool show_slave_hosts(THD* thd)
}
}
pthread_mutex_unlock(&LOCK_slave_list);
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
diff --git a/sql/slave.cc b/sql/slave.cc
index ea0dde942da..d9dc014b025 100644
--- a/sql/slave.cc
+++ b/sql/slave.cc
@@ -1451,7 +1451,7 @@ bool show_master_info(THD* thd, Master_info* mi)
if (my_net_write(&thd->net, (uchar*) thd->packet.ptr(), packet->length()))
DBUG_RETURN(TRUE);
}
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
diff --git a/sql/sp.cc b/sql/sp.cc
index e69bf83d552..b486e58883a 100644
--- a/sql/sp.cc
+++ b/sql/sp.cc
@@ -1259,7 +1259,7 @@ sp_show_status_routine(THD *thd, int type, const char *name_pattern)
}
err_case1:
- send_eof(thd);
+ my_eof(thd);
err_case:
table->file->ha_index_end();
close_thread_tables(thd);
diff --git a/sql/sp_head.cc b/sql/sp_head.cc
index 1d443b70737..f42a5dde8ed 100644
--- a/sql/sp_head.cc
+++ b/sql/sp_head.cc
@@ -2419,7 +2419,7 @@ sp_head::show_create_routine(THD *thd, int type)
err_status= protocol->write();
if (!err_status)
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(err_status);
}
@@ -2611,7 +2611,7 @@ sp_head::show_routine_code(THD *thd)
}
if (!res)
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(res);
}
diff --git a/sql/sql_acl.cc b/sql/sql_acl.cc
index 040a7822d9d..3805d9fa8b6 100644
--- a/sql/sql_acl.cc
+++ b/sql/sql_acl.cc
@@ -4815,7 +4815,7 @@ end:
VOID(pthread_mutex_unlock(&acl_cache->lock));
rw_unlock(&LOCK_grant);
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(error);
}
diff --git a/sql/sql_class.cc b/sql/sql_class.cc
index 1fb3fc74151..3ce1b350027 100644
--- a/sql/sql_class.cc
+++ b/sql/sql_class.cc
@@ -1548,7 +1548,7 @@ bool select_send::send_eof()
mysql_unlock_tables(thd, thd->lock);
thd->lock=0;
}
- ::send_eof(thd);
+ ::my_eof(thd);
is_result_set_started= 0;
return FALSE;
}
diff --git a/sql/sql_error.cc b/sql/sql_error.cc
index 89cff73d153..0b74e3455eb 100644
--- a/sql/sql_error.cc
+++ b/sql/sql_error.cc
@@ -249,6 +249,6 @@ bool mysqld_show_warnings(THD *thd, ulong levels_to_show)
if (protocol->write())
DBUG_RETURN(TRUE);
}
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
diff --git a/sql/sql_handler.cc b/sql/sql_handler.cc
index 3d47d16ea56..28a9fb5c78e 100644
--- a/sql/sql_handler.cc
+++ b/sql/sql_handler.cc
@@ -658,7 +658,7 @@ retry:
}
ok:
mysql_unlock_tables(thd,lock);
- send_eof(thd);
+ my_eof(thd);
DBUG_PRINT("exit",("OK"));
DBUG_RETURN(FALSE);
diff --git a/sql/sql_help.cc b/sql/sql_help.cc
index 0d633ce86ac..e424425272e 100644
--- a/sql/sql_help.cc
+++ b/sql/sql_help.cc
@@ -779,7 +779,7 @@ bool mysqld_help(THD *thd, const char *mask)
if (send_variant_2_list(mem_root,protocol, &categories_list, "Y", 0))
goto error;
}
- send_eof(thd);
+ my_eof(thd);
close_system_tables(thd, &open_tables_state_backup);
DBUG_RETURN(FALSE);
diff --git a/sql/sql_parse.cc b/sql/sql_parse.cc
index 11fa77ca2fc..a78ac978a4a 100644
--- a/sql/sql_parse.cc
+++ b/sql/sql_parse.cc
@@ -1348,7 +1348,7 @@ bool dispatch_command(enum enum_server_command command, THD *thd,
}
DBUG_PRINT("quit",("Got shutdown command for level %u", level));
general_log_print(thd, command, NullS);
- send_eof(thd);
+ my_eof(thd);
close_thread_tables(thd); // Free before kill
kill_mysql();
error=TRUE;
@@ -1434,11 +1434,11 @@ bool dispatch_command(enum enum_server_command command, THD *thd,
switch (opt_command) {
case (int) MYSQL_OPTION_MULTI_STATEMENTS_ON:
thd->client_capabilities|= CLIENT_MULTI_STATEMENTS;
- send_eof(thd);
+ my_eof(thd);
break;
case (int) MYSQL_OPTION_MULTI_STATEMENTS_OFF:
thd->client_capabilities&= ~CLIENT_MULTI_STATEMENTS;
- send_eof(thd);
+ my_eof(thd);
break;
default:
my_message(ER_UNKNOWN_COM_ERROR, ER(ER_UNKNOWN_COM_ERROR), MYF(0));
@@ -1452,7 +1452,7 @@ bool dispatch_command(enum enum_server_command command, THD *thd,
break; /* purecov: inspected */
mysql_print_status();
general_log_print(thd, command, NullS);
- send_eof(thd);
+ my_eof(thd);
break;
case COM_SLEEP:
case COM_CONNECT: // Impossible here
diff --git a/sql/sql_prepare.cc b/sql/sql_prepare.cc
index e03f7cfb6a0..02d8ed00c32 100644
--- a/sql/sql_prepare.cc
+++ b/sql/sql_prepare.cc
@@ -2662,7 +2662,7 @@ bool Select_fetch_protocol_binary::send_fields(List<Item> &list, uint flags)
bool Select_fetch_protocol_binary::send_eof()
{
- ::send_eof(thd);
+ ::my_eof(thd);
return FALSE;
}
diff --git a/sql/sql_repl.cc b/sql/sql_repl.cc
index 573a257cd3d..932b7a67b4d 100644
--- a/sql/sql_repl.cc
+++ b/sql/sql_repl.cc
@@ -738,7 +738,7 @@ end:
end_io_cache(&log);
(void)my_close(file, MYF(MY_WME));
- send_eof(thd);
+ my_eof(thd);
thd_proc_info(thd, "Waiting to finalize termination");
pthread_mutex_lock(&LOCK_thread_count);
thd->current_linfo = 0;
@@ -1453,7 +1453,7 @@ err:
my_error(ER_ERROR_WHEN_EXECUTING_COMMAND, MYF(0),
"SHOW BINLOG EVENTS", errmsg);
else
- send_eof(thd);
+ my_eof(thd);
pthread_mutex_lock(&LOCK_thread_count);
thd->current_linfo = 0;
@@ -1490,7 +1490,7 @@ bool show_binlog_info(THD* thd)
if (protocol->write())
DBUG_RETURN(TRUE);
}
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
@@ -1572,7 +1572,7 @@ bool show_binlogs(THD* thd)
goto err;
}
mysql_bin_log.unlock_index();
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
err:
diff --git a/sql/sql_show.cc b/sql/sql_show.cc
index 6d817cb0620..9f56933a114 100644
--- a/sql/sql_show.cc
+++ b/sql/sql_show.cc
@@ -224,7 +224,7 @@ bool mysqld_show_authors(THD *thd)
if (protocol->write())
DBUG_RETURN(TRUE);
}
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
@@ -258,7 +258,7 @@ bool mysqld_show_contributors(THD *thd)
if (protocol->write())
DBUG_RETURN(TRUE);
}
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
@@ -331,7 +331,7 @@ bool mysqld_show_privileges(THD *thd)
if (protocol->write())
DBUG_RETURN(TRUE);
}
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
@@ -419,7 +419,7 @@ bool mysqld_show_column_types(THD *thd)
if (protocol->write())
DBUG_RETURN(TRUE);
}
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
@@ -666,7 +666,7 @@ mysqld_show_create(THD *thd, TABLE_LIST *table_list)
if (protocol->write())
DBUG_RETURN(TRUE);
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
@@ -747,7 +747,7 @@ bool mysqld_show_create_db(THD *thd, char *dbname,
if (protocol->write())
DBUG_RETURN(TRUE);
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
}
@@ -789,7 +789,7 @@ mysqld_list_fields(THD *thd, TABLE_LIST *table_list, const char *wild)
table->use_all_columns();
if (thd->protocol->send_fields(&field_list, Protocol::SEND_DEFAULTS))
DBUG_VOID_RETURN;
- send_eof(thd);
+ my_eof(thd);
DBUG_VOID_RETURN;
}
@@ -1738,7 +1738,7 @@ void mysqld_list_processes(THD *thd,const char *user, bool verbose)
if (protocol->write())
break; /* purecov: inspected */
}
- send_eof(thd);
+ my_eof(thd);
DBUG_VOID_RETURN;
}
@@ -6760,7 +6760,7 @@ static bool show_create_trigger_impl(THD *thd,
ret_code= p->write();
if (!ret_code)
- send_eof(thd);
+ my_eof(thd);
return ret_code != 0;
}
diff --git a/sql/sql_table.cc b/sql/sql_table.cc
index 07ba9d0ec56..c62d0545fda 100644
--- a/sql/sql_table.cc
+++ b/sql/sql_table.cc
@@ -4501,7 +4501,7 @@ send_result_message:
goto err;
}
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
err:
@@ -7311,7 +7311,7 @@ bool mysql_checksum_table(THD *thd, TABLE_LIST *tables,
goto err;
}
- send_eof(thd);
+ my_eof(thd);
DBUG_RETURN(FALSE);
err:
diff --git a/sql/sql_class.h b/sql/sql_class.h
index 565375fef95..2f225834545 100644
--- a/sql/sql_class.h
+++ b/sql/sql_class.h
@@ -995,7 +995,7 @@ public:
DA_EMPTY= 0,
/** Set whenever one calls my_ok(). */
DA_OK,
/** Set whenever one calls send_eof(). */
DA_EOF,
/** Set whenever one calls my_error() or my_message(). */
DA_ERROR,
@@ -1063,7 +1063,7 @@ private:
Copied from thd->server_status when the diagnostics area is assigned.
We need this member as some places in the code use the following pattern:
thd->server_status|= ...
- send_eof(thd);
+ my_eof(thd);
thd->server_status&= ~...
Assigned by OK, EOF or ERROR.
*/
@@ -2151,7 +2151,7 @@ my_ok(THD *thd, ha_rows affected_rows= 0, ulonglong id= 0,
/** A short cut for thd->main_da.set_eof_status(). */
inline void
-send_eof(THD *thd)
+my_eof(THD *thd)
{
thd->main_da.set_eof_status(thd);
}
@@ -995,7 +995,7 @@ public:
/** Set whenever one calls my_ok(). */
DA_OK,
- /** Set whenever one calls send_eof(). */
+ /** Set whenever one calls my_eof(). */
DA_EOF,
/** Set whenever one calls my_error() or my_message(). */